==> sigutils-2.2.6.tar.gz: sigutils-2.2.6/SigUtils/ajustar_empresa.py <==
# -*- encoding: utf-8 -*-

import xmlrpclib, socket
import re

#TODO remover os parametros "local" e "servidor_local", não são mais necessários
def sigutils_conversar_com_a_sig(servidor, classe, metodo, dados, local='N', servidor_local=None):
    """
    Classe de comunicação com o servidor da sig
    @param servidor: lista com dados do servidor, host, base, porta, usuario, senha
    @param classe: Classe para conversa exemplo: adm.pessoa
    @param metodo: Método a ser executado. exemplo: create
    @param dados: dados a serem passados para o método
    @param local: se local, = 'S" não faz comunicacao porque está na sig, mas retorna como se tivesse feito
    @param servidor_local, somente usado quando local for = S
    @return: boolean
    """
    hostname = servidor[0]
    username = servidor[3]
    pwd = servidor[4]
    db = servidor[1]
    porta = servidor[2]
    _rem_senha = 'ml_remoto_77813'
    _rem_usuario = 'ml_remoto'
    try:
        if local != 'N':
            sock_common = xmlrpclib.ServerProxy(
                  'http://' + servidor_local + ':' + str(porta) + '/xmlrpc/common')
            socket.setdefaulttimeout(2)
            try:
                uid = sock_common.login(db, _rem_usuario, _rem_senha)
            except:
                uid = False
            if uid:
                return True
        sock_common = xmlrpclib.ServerProxy(
            'http://' + hostname + ':' + str(porta) + '/xmlrpc/common')
        socket.setdefaulttimeout(3)
        uid = sock_common.login(db, username, pwd)
        sock = xmlrpclib.ServerProxy('http://' + hostname + ':' + str(porta) + '/xmlrpc/object')
        _conseguiu = sock.execute(db, uid, pwd, classe, metodo, dados)
    except Exception as e:
        _conseguiu = False
    return _conseguiu


def sigutils_ajustar_empresa(pessoa_dados, telefone_dados, endereco_dados, email_dados):
    hostname = 'erp.siginformatica.com.br'
    username = 'remoto'
    pwd = 'remo102938'
    db = 'erp'
    porta = '8069'

    try:
        sock_common = xmlrpclib.ServerProxy(
            'http://' + hostname + ':' + str(porta) + '/xmlrpc/common')
        socket.setdefaulttimeout(3)
        uid = sock_common.login(db, username, pwd)
        sock = xmlrpclib.ServerProxy('http://' + hostname + ':' + str(porta) + '/xmlrpc/object')

        cnpj = pessoa_dados.get('cpf_cnpj')
        # Para empresas com cnpj da sig, não atualizar
        if cnpj == '01.526.558/0001-78' or cnpj == '08.974.572/0001-83':
            return True
        atualizou = True
        ids = sock.execute(db, uid, pwd, 'adm.pessoa', 'search', [('cpf_cnpj', '=', cnpj)])
        if ids:
            sock.execute(db, uid, pwd, 'adm.pessoa', 'write', ids[0], pessoa_dados)
        else:
            ids = sock.execute(db, uid, pwd, 'adm.pessoa', 'create', pessoa_dados)
        if isinstance(ids, list):
            ids = ids[0]
        for i in telefone_dados:
            telefone_tipo = i.get('telefone_tipo_id')
            telefone_tipo_id = False
            if telefone_tipo:
                telefone_tipo_id = sock.execute(db, uid, pwd, 'adm.telefone.tipo', 'search',
                                                [('name', 'ilike', telefone_tipo)])
                if not telefone_tipo_id:
                    telefone_tipo_id = sock.execute(db, uid, pwd, 'adm.telefone.tipo', 'create',
                                                    {'name': telefone_tipo})
                if isinstance(telefone_tipo_id, list):
                    telefone_tipo_id = telefone_tipo_id[0]

            args = []
            if i.get('ddi'):
                i['ddi'] = re.sub('[^0-9]', '', i.get('ddi'))
            if i.get('ddd'):
                i['ddd'] = re.sub('[^0-9]', '', i.get('ddd'))
            if i.get('numero'):
                i['numero'] = re.sub('[^0-9]', '', i.get('numero'))
            args.append(('pessoa_id', '=', ids))
            args.append(('ddd', '=', i.get('ddd')))
            args.append(('numero', '=', i.get('numero')))
            telefone_id = sock.execute(db, uid, pwd, 'adm.pessoa.telefone', 'search', args)

            if not telefone_id:
                vals = {
                    'pessoa_id': ids,
                    'telefone_tipo_id': telefone_tipo_id,
                    'ddi': i.get('ddi'),
                    'ddd': i.get('ddd'),
                    'numero': i.get('numero'),
                    'observacoes': i.get('observacoes')
                }
                sock.execute(db, uid, pwd, 'adm.pessoa.telefone', 'create', vals)
        for i in endereco_dados:
            pais = i.get('pais_id')
            pais_id = False
            if pais:
                pais_id = sock.execute(db, uid, pwd, 'adm.pais', 'search',
                                       [('name', 'ilike', pais)])
                if not pais_id:
                    pais_id = sock.execute(db, uid, pwd, 'adm.pais', 'create',
                                           {'name': pais, 'sigla': pais[:3]})
                if isinstance(pais_id, list):
                    pais_id = pais_id[0]
            if not pais_id:
                continue
            logradouro_id = i.get('logradouro_id')
            if logradouro_id:
                logradouro = logradouro_id.split(' ')
                titulo = logradouro[0]
                descricao = ''
                for b in range(1, len(logradouro)):
                    descricao += logradouro[b] + ' '
                logradouro_id = sock.execute(db, uid, pwd, 'adm.logradouro', 'search',
                                             [('titulo', 'ilike', titulo),
                                              ('descricao', 'ilike', descricao)])
                if not logradouro_id:
                    vals = {
                        'titulo': titulo,
                        'descricao': descricao,
                    }
                    logradouro_id = sock.execute(db, uid, pwd, 'adm.logradouro', 'create', vals)
                if isinstance(logradouro_id, list):
                    logradouro_id = logradouro_id[0]
            uf = i.get('uf_id')
            uf_id = False
            if uf and pais_id:
                uf_id = sock.execute(db, uid, pwd, 'adm.uf', 'search',
                                     [('name', 'ilike', uf), ('pais_id', '=', pais_id)])
                if not uf_id:
                    vals = {
                        'pais_id': pais_id,
                        'sigla': uf[:2],
                        'name': uf,
                    }
                    uf_id = sock.execute(db, uid, pwd, 'adm.uf', 'create', vals)
                if isinstance(uf_id, list):
                    uf_id = uf_id[0]
            if not uf_id:
                continue
            cidade = i.get('cidade_id')
            cidade_id = False
            if cidade and uf_id:
                cidade_id = sock.execute(db, uid, pwd, 'adm.cidade', 'search',
                                         [('name', 'ilike', cidade), ('uf_id', '=', uf_id)])
                if not cidade_id:
                    vals = {
                        'uf_id': uf_id,
                        'name': cidade,
                        'pais_id': pais_id,
                    }
                    cidade_id = sock.execute(db, uid, pwd, 'adm.cidade', 'create', vals)
                if isinstance(cidade_id, list):
                    cidade_id = cidade_id[0]
            endereco_tipo_id = i.get('endereco_tipo_id')
            if endereco_tipo_id:
                endereco_tipo_id = sock.execute(db, uid, pwd, 'adm.endereco.tipo', 'search',
                                                [('name', '=', endereco_tipo_id)])
                if not endereco_tipo_id:
                    endereco_tipo_id = sock.execute(db, uid, pwd, 'adm.endereco.tipo', 'create',
                                                    {'name': endereco_tipo_id})
                if isinstance(endereco_tipo_id, list):
                    endereco_tipo_id = endereco_tipo_id[0]
            regiao = i.get('regiao_id')
            regiao_id = False
            if regiao:
                regiao_id = sock.execute(db, uid, pwd, 'adm.regiao', 'search',
                                         [('name', 'ilike', regiao)])
                if not regiao_id:
                    regiao_id = sock.execute(db, uid, pwd, 'adm.regiao', 'create', {'name': regiao})
                if isinstance(regiao_id, list):
                    regiao_id = regiao_id[0]
            bairro = i.get('bairro_id')
            bairro_id = False
            if bairro:
                bairro_id = sock.execute(db, uid, pwd, 'adm.bairro', 'search',
                                         [('name', 'ilike', bairro)])
                if not bairro_id:
                    bairro_id = sock.execute(db, uid, pwd, 'adm.bairro', 'create', {'name': bairro})
                if isinstance(bairro_id, list):
                    bairro_id = bairro_id[0]

            args = []
            args.append(('pessoa_id', '=', ids))
            args.append(('endereco_tipo_id', '=', endereco_tipo_id))
            args.append(('pais_id', '=', pais_id))
            args.append(('uf_id', '=', uf_id))
            args.append(('cidade_id', '=', cidade_id))
            if bairro_id:
                args.append(('bairro_id', '=', bairro_id))
            args.append(('logradouro_id', '=', logradouro_id))
            args.append(('numero', '=', i.get('numero')))
            args.append(('complemento', '=', i.get('complemento')))
            args.append(('cep', '=', i.get('cep')))

            endereco_id = sock.execute(db, uid, pwd, 'adm.pessoa.endereco', 'search', args)

            if not endereco_id:
                vals = {
                    'pessoa_id': ids,
                    'endereco_tipo_id': endereco_tipo_id,
                    'pais_id': pais_id,
                    'uf_id': uf_id,
                    'cidade_id': cidade_id,
                    'logradouro_id': logradouro_id,
                    'active': i.get('active'),

                }
                if bairro_id:
                    vals['bairro_id'] = bairro_id
                if i.get('complemento'):
                    vals['complemento'] = i.get('complemento')
                if i.get('regiao_id'):
                    vals['regiao_id'] = regiao_id
                if i.get('observacao'):
                    vals['observacao'] = i.get('observacao')
                if i.get('numero'):
                    vals['numero'] = i.get('numero')
                if i.get('cep'):
                    vals['cep'] = i.get('cep')

                sock.execute(db, uid, pwd, 'adm.pessoa.endereco', 'create', vals)

        for i in email_dados:
            email_tipo = i.get('email_tipo_id')
            email_tipo_id = False
            if email_tipo:
                email_tipo_id = sock.execute(db, uid, pwd, 'adm.email.tipo', 'search',
                                             [('name', 'ilike', email_tipo)])
                if not email_tipo_id:
                    email_tipo_id = sock.execute(db, uid, pwd, 'adm.email.tipo', 'create',
                                                 {'name': email_tipo})
                if isinstance(email_tipo_id, list):
                    email_tipo_id = email_tipo_id[0]

            args = []
            args.append(('pessoa_id', '=', ids))
            args.append(('email_tipo_id', '=', email_tipo_id))
            args.append(('name', 'ilike', i.get('name')))

            email_id = sock.execute(db, uid, pwd, 'adm.pessoa.email', 'search', args)

            if not email_id:
                vals = {
                    'pessoa_id': ids,
                    'email_tipo_id': email_tipo_id,
                    'name': i.get('name'),
                    'observacoes': i.get('observacoes')
                }
                sock.execute(db, uid, pwd, 'adm.pessoa.email', 'create', vals)
    except:
        atualizou = False

    return atualizou

==> sigutils-2.2.7.tar.gz: sigutils-2.2.7/SigUtils/ajustar_empresa.py <==
# -*- encoding: utf-8 -*-

import xmlrpclib, socket
import re

#TODO remover os parametros "local" e "servidor_local", não são mais necessários
def sigutils_conversar_com_a_sig(servidor, classe, metodo, dados, local='N', servidor_local=None):
    """
    Classe de comunicação com o servidor da sig
    @param servidor: lista com dados do servidor, host, base, porta, usuario, senha
    @param classe: Classe para conversa exemplo: adm.pessoa
    @param metodo: Método a ser executado. exemplo: create
    @param dados: dados a serem passados para o método
    @param local: se local, = 'S" não faz comunicacao porque está na sig, mas retorna como se tivesse feito
    @param servidor_local, somente usado quando local for = S
    @return: boolean
    """
    hostname = servidor[0]
    username = servidor[3]
    pwd = servidor[4]
    db = servidor[1]
    porta = servidor[2]
    _rem_senha = 'remo102938'
    _rem_usuario = 'remoto'
    try:
        if local != 'N':
            sock_common = xmlrpclib.ServerProxy(
                  'http://' + servidor_local + ':' + str(porta) + '/xmlrpc/common')
            socket.setdefaulttimeout(2)
            try:
                uid = sock_common.login(db, _rem_usuario, _rem_senha)
            except:
                uid = False
            if uid:
                return True
        sock_common = xmlrpclib.ServerProxy(
            'http://' + hostname + ':' + str(porta) + '/xmlrpc/common')
        socket.setdefaulttimeout(3)
        uid = sock_common.login(db, username, pwd)
        sock = xmlrpclib.ServerProxy('http://' + hostname + ':' + str(porta) + '/xmlrpc/object')
        _conseguiu = sock.execute(db, uid, pwd, classe, metodo, dados)
    except Exception as e:
        _conseguiu = False
    return _conseguiu


def sigutils_ajustar_empresa(pessoa_dados, telefone_dados, endereco_dados, email_dados):
    hostname = 'erp.siginformatica.com.br'
    username = 'remoto'
    pwd = 'remo102938'
    db = 'erp'
    porta = '8069'

    try:
        sock_common = xmlrpclib.ServerProxy(
            'http://' + hostname + ':' + str(porta) + '/xmlrpc/common')
        socket.setdefaulttimeout(3)
        uid = sock_common.login(db, username, pwd)
        sock = xmlrpclib.ServerProxy('http://' + hostname + ':' + str(porta) + '/xmlrpc/object')

        cnpj = pessoa_dados.get('cpf_cnpj')
        # Para empresas com cnpj da sig, não atualizar
        if cnpj == '01.526.558/0001-78' or cnpj == '08.974.572/0001-83':
            return True
        atualizou = True
        ids = sock.execute(db, uid, pwd, 'adm.pessoa', 'search', [('cpf_cnpj', '=', cnpj)])
        if ids:
            sock.execute(db, uid, pwd, 'adm.pessoa', 'write', ids[0], pessoa_dados)
        else:
            ids = sock.execute(db, uid, pwd, 'adm.pessoa', 'create', pessoa_dados)
        if isinstance(ids, list):
            ids = ids[0]
        for i in telefone_dados:
            telefone_tipo = i.get('telefone_tipo_id')
            telefone_tipo_id = False
            if telefone_tipo:
                telefone_tipo_id = sock.execute(db, uid, pwd, 'adm.telefone.tipo', 'search',
                                                [('name', 'ilike', telefone_tipo)])
                if not telefone_tipo_id:
                    telefone_tipo_id = sock.execute(db, uid, pwd, 'adm.telefone.tipo', 'create',
                                                    {'name': telefone_tipo})
                if isinstance(telefone_tipo_id, list):
                    telefone_tipo_id = telefone_tipo_id[0]

            args = []
            if i.get('ddi'):
                i['ddi'] = re.sub('[^0-9]', '', i.get('ddi'))
            if i.get('ddd'):
                i['ddd'] = re.sub('[^0-9]', '', i.get('ddd'))
            if i.get('numero'):
                i['numero'] = re.sub('[^0-9]', '', i.get('numero'))
            args.append(('pessoa_id', '=', ids))
            args.append(('ddd', '=', i.get('ddd')))
            args.append(('numero', '=', i.get('numero')))
            telefone_id = sock.execute(db, uid, pwd, 'adm.pessoa.telefone', 'search', args)

            if not telefone_id:
                vals = {
                    'pessoa_id': ids,
                    'telefone_tipo_id': telefone_tipo_id,
                    'ddi': i.get('ddi'),
                    'ddd': i.get('ddd'),
                    'numero': i.get('numero'),
                    'observacoes': i.get('observacoes')
                }
                sock.execute(db, uid, pwd, 'adm.pessoa.telefone', 'create', vals)
        for i in endereco_dados:
            pais = i.get('pais_id')
            pais_id = False
            if pais:
                pais_id = sock.execute(db, uid, pwd, 'adm.pais', 'search',
                                       [('name', 'ilike', pais)])
                if not pais_id:
                    pais_id = sock.execute(db, uid, pwd, 'adm.pais', 'create',
                                           {'name': pais, 'sigla': pais[:3]})
                if isinstance(pais_id, list):
                    pais_id = pais_id[0]
            if not pais_id:
                continue
            logradouro_id = i.get('logradouro_id')
            if logradouro_id:
                logradouro = logradouro_id.split(' ')
                titulo = logradouro[0]
                descricao = ''
                for b in range(1, len(logradouro)):
                    descricao += logradouro[b] + ' '
                logradouro_id = sock.execute(db, uid, pwd, 'adm.logradouro', 'search',
                                             [('titulo', 'ilike', titulo),
                                              ('descricao', 'ilike', descricao)])
                if not logradouro_id:
                    vals = {
                        'titulo': titulo,
                        'descricao': descricao,
                    }
                    logradouro_id = sock.execute(db, uid, pwd, 'adm.logradouro', 'create', vals)
                if isinstance(logradouro_id, list):
                    logradouro_id = logradouro_id[0]
            uf = i.get('uf_id')
            uf_id = False
            if uf and pais_id:
                uf_id = sock.execute(db, uid, pwd, 'adm.uf', 'search',
                                     [('name', 'ilike', uf), ('pais_id', '=', pais_id)])
                if not uf_id:
                    vals = {
                        'pais_id': pais_id,
                        'sigla': uf[:2],
                        'name': uf,
                    }
                    uf_id = sock.execute(db, uid, pwd, 'adm.uf', 'create', vals)
                if isinstance(uf_id, list):
                    uf_id = uf_id[0]
            if not uf_id:
                continue
            cidade = i.get('cidade_id')
            cidade_id = False
            if cidade and uf_id:
                cidade_id = sock.execute(db, uid, pwd, 'adm.cidade', 'search',
                                         [('name', 'ilike', cidade), ('uf_id', '=', uf_id)])
                if not cidade_id:
                    vals = {
                        'uf_id': uf_id,
                        'name': cidade,
                        'pais_id': pais_id,
                    }
                    cidade_id = sock.execute(db, uid, pwd, 'adm.cidade', 'create', vals)
                if isinstance(cidade_id, list):
                    cidade_id = cidade_id[0]
            endereco_tipo_id = i.get('endereco_tipo_id')
            if endereco_tipo_id:
                endereco_tipo_id = sock.execute(db, uid, pwd, 'adm.endereco.tipo', 'search',
                                                [('name', '=', endereco_tipo_id)])
                if not endereco_tipo_id:
                    endereco_tipo_id = sock.execute(db, uid, pwd, 'adm.endereco.tipo', 'create',
                                                    {'name': endereco_tipo_id})
                if isinstance(endereco_tipo_id, list):
                    endereco_tipo_id = endereco_tipo_id[0]
            regiao = i.get('regiao_id')
            regiao_id = False
            if regiao:
                regiao_id = sock.execute(db, uid, pwd, 'adm.regiao', 'search',
                                         [('name', 'ilike', regiao)])
                if not regiao_id:
                    regiao_id = sock.execute(db, uid, pwd, 'adm.regiao', 'create', {'name': regiao})
                if isinstance(regiao_id, list):
                    regiao_id = regiao_id[0]
            bairro = i.get('bairro_id')
            bairro_id = False
            if bairro:
                bairro_id = sock.execute(db, uid, pwd, 'adm.bairro', 'search',
                                         [('name', 'ilike', bairro)])
                if not bairro_id:
                    bairro_id = sock.execute(db, uid, pwd, 'adm.bairro', 'create', {'name': bairro})
                if isinstance(bairro_id, list):
                    bairro_id = bairro_id[0]

            args = []
            args.append(('pessoa_id', '=', ids))
            args.append(('endereco_tipo_id', '=', endereco_tipo_id))
            args.append(('pais_id', '=', pais_id))
            args.append(('uf_id', '=', uf_id))
            args.append(('cidade_id', '=', cidade_id))
            if bairro_id:
                args.append(('bairro_id', '=', bairro_id))
            args.append(('logradouro_id', '=', logradouro_id))
            args.append(('numero', '=', i.get('numero')))
            args.append(('complemento', '=', i.get('complemento')))
            args.append(('cep', '=', i.get('cep')))

            endereco_id = sock.execute(db, uid, pwd, 'adm.pessoa.endereco', 'search', args)

            if not endereco_id:
                vals = {
                    'pessoa_id': ids,
                    'endereco_tipo_id': endereco_tipo_id,
                    'pais_id': pais_id,
                    'uf_id': uf_id,
                    'cidade_id': cidade_id,
                    'logradouro_id': logradouro_id,
                    'active': i.get('active'),

                }
                if bairro_id:
                    vals['bairro_id'] = bairro_id
                if i.get('complemento'):
                    vals['complemento'] = i.get('complemento')
                if i.get('regiao_id'):
                    vals['regiao_id'] = regiao_id
                if i.get('observacao'):
                    vals['observacao'] = i.get('observacao')
                if i.get('numero'):
                    vals['numero'] = i.get('numero')
                if i.get('cep'):
                    vals['cep'] = i.get('cep')

                sock.execute(db, uid, pwd, 'adm.pessoa.endereco', 'create', vals)

        for i in email_dados:
            email_tipo = i.get('email_tipo_id')
            email_tipo_id = False
            if email_tipo:
                email_tipo_id = sock.execute(db, uid, pwd, 'adm.email.tipo', 'search',
                                             [('name', 'ilike', email_tipo)])
                if not email_tipo_id:
                    email_tipo_id = sock.execute(db, uid, pwd, 'adm.email.tipo', 'create',
                                                 {'name': email_tipo})
                if isinstance(email_tipo_id, list):
                    email_tipo_id = email_tipo_id[0]

            args = []
            args.append(('pessoa_id', '=', ids))
            args.append(('email_tipo_id', '=', email_tipo_id))
            args.append(('name', 'ilike', i.get('name')))

            email_id = sock.execute(db, uid, pwd, 'adm.pessoa.email', 'search', args)

            if not email_id:
                vals = {
                    'pessoa_id': ids,
                    'email_tipo_id': email_tipo_id,
                    'name': i.get('name'),
                    'observacoes': i.get('observacoes')
                }
                sock.execute(db, uid, pwd, 'adm.pessoa.email', 'create', vals)
    except:
        atualizou = False

    return atualizou
